@@ -1,14 +1,13 @@
-;;;;# -*-coding:utf-8;-*-                                               µ ← col73
+;;;;# -*-coding:utf-8;-*-                                               µ
 
 require 5;
 use 5.8.0;
-package Text::Unidecode;
-$Last_Modified =' Time-stamp: "2015-10-16 02:39:22 MDT sburke@cpan.org"';
+package Text::Unidecode;  # Time-stamp: "2014-06-30 01:54:22 MDT sburke@cpan.org"
 use utf8;
 use strict;
 use integer; # vroom vroom!
-use vars qw($VERSION @ISA @EXPORT @Char $UNKNOWN $NULLMAP $TABLE_SIZE $Last_Modified);
-$VERSION = '1.25_01';
+use vars qw($VERSION @ISA @EXPORT @Char $UNKNOWN $NULLMAP $TABLE_SIZE);
+$VERSION = '1.01';
 require Exporter;
 @ISA = ('Exporter');
 @EXPORT = ('unidecode');
@@ -45,23 +44,18 @@ sub unidecode {
 
   foreach my $n (@_) {
     next unless defined $n;    
-
-    # Shut up potentially fatal warnings about UTF-16 surrogate
-    # characters when running under perl -w
-    # This is per https://rt.cpan.org/Ticket/Display.html?id=97456
-    no warnings 'utf8';
-
     $n =~ s~([^\x00-\x7f])~${$Char[ord($1)>>8]||t($1)}[ord($1)&255]~egs;
   }
-  # That means:
-  #   Replace character 0xABCD with $Char[0xAB][0xCD], loading
-  #    the table 0xAB as needed.
+  # Replace character 0xABCD with $Char[0xAB][0xCD], loading
+  #  the table as needed.
   #
   #======================================================================
   #
   # Yes, that's dense code.  It's the warp core!
   # Here is an expansion into pseudocode... as best as I can manage it...
   #
+  #   
+  #  
   #     $character = $1;
   #     $charnum = ord($character);
   #     $charnum_lowbits  = $charnum & 255;
@@ -101,8 +95,8 @@ sub unidecode {
   #       use other delimiters, such as "s!!!" and "s{}{}", 
   #  I didn't do it for sake of obscurity. I think it's just to
   #  keep my editor's syntax highlighter from crashing,
-  #  which was a problem with s/// when the insides are as gory
-  #  as we have here.
+  #  which was a problem with s///
+  #
 
   return unless defined wantarray; # void context
   return @_ if wantarray;  # normal list context -- return the copies
@@ -113,22 +107,17 @@ sub unidecode {
 
 #======================================================================
 
-sub make_placeholder_map {
-  return [( $UNKNOWN ) x $TABLE_SIZE ];
-}
-sub make_placeholder_map_nulls {
-  return [( "" ) x $TABLE_SIZE ];
-}
-
-#======================================================================
-
 sub t {   # "t" is for "t"able.
   # Load (and return) a char table for this character
   # this should get called only once per table per session.
   my $bank = ord($_[0]) >> 8;
   return $Char[$bank] if $Char[$bank];
- 
-  load_bank($bank);
+  
+  {
+    DEBUG and printf "Loading %s::x%02x\n", __PACKAGE__, $bank;
+    local $SIG{'__DIE__'};
+    eval(sprintf 'require %s::x%02x;', __PACKAGE__, $bank);
+  }
         
   # Now see how that fared...
 
@@ -184,40 +173,7 @@ sub t {   # "t" is for "t"able.
   return $Char[$bank];
 }
 
-#-----------------------------------------------------------------------
-
-our $eval_loaded_okay;
-
-sub load_bank {
-
-  # This is in its own sub, for sake of sweeping the scary thing
-  #  (namely, a call to eval) under the rug.
-  # I.e., to paraphrase what Larry Wall once said to me: if
-  #  you're going to do something odd, maybe you should do it
-  #  in private.
-
-  my($banknum) = @_;  # just as an integer value
-
-  DEBUG and printf
-      "# Eval-loading %s::x%02x ...\n";
-
-  $eval_loaded_okay = 0;
-  my $code = 
-      sprintf( "require %s::x%02x; \$eval_loaded_okay = 1;\n",
-               __PACKAGE__,
-	       $banknum);
-
-  {
-    local $SIG{'__DIE__'};
-    eval($code);
-  }
-
-  return 1 if $eval_loaded_okay;
-  return 0;
-}
-
-#======================================================================
-
+#--------------------------------------------------------------------------
 1;
 __END__
 
@@ -322,22 +278,22 @@ is exported by default.  It can be used in a variety of calling contexts:
 
 =over
 
-=item C<$out = unidecode( $in );> # scalar context
+=item C<$out = unidecode($in);> # scalar context
 
 This returns a copy of $in, transliterated.
 
-=item C<$out = unidecode( @in );> # scalar context
+=item C<$out = unidecode(@in);> # scalar context
 
 This is the same as C<$out = unidecode(join "", @in);>
 
-=item C<@out = unidecode( @in );> # list context
+=item C<@out = unidecode(@in);> # list context
 
 This returns a list consisting of copies of @in, each transliterated.  This
 is the same as C<@out = map scalar(unidecode($_)), @in;>
 
-=item C<unidecode( @items );> # void context
+=item C<unidecode(@items);> # void context
 
-=item C<unidecode( @bar, $foo, @baz );> # void context
+=item C<unidecode(@bar, $foo, @baz);> # void context
 
 Each item on input is replaced with its transliteration.  This
 is the same as C<for(@bar, $foo, @baz) { $_ = unidecode($_) }>
@@ -400,19 +356,19 @@ be better transliterated as "D", I I<may> well make that change.
 
 Unfortunately, there are many characters that Unidecode doesn't know a
 transliteration for.  This is generally because the character has been
-added since I last revised the Unidecode data tables.  I'm I<always>
+added since I last revised the Unidecode data tables.  I'm always
 catching up!
 
 =back
 
 =head1 DESIGN GOALS AND CONSTRAINTS
 
-Text::Unidecode is meant to be a transliterator of last resort,
+Text::Unidecode is meant to be a transliterator-of-last resort,
 to be used once you've decided that you can't just display the
 Unicode data as is, I<and once you've decided you don't have a
 more clever, language-specific transliterator available,> or once
-you've I<already applied> smarter algorithms or mappings that you prefer
-and you now just want Unidecode to do cleanup.
+you've I<already applied> a smarter algorithm and now just want Unidecode
+to do cleanup.
 
 Unidecode
 transliterates context-insensitively-- that is, a given character is
@@ -507,12 +463,6 @@ with /-shaped accents on the "e" characters.
 
 =item *
 
-"læti" should be I<four> letters long-- the second letter should not
-be two letters "ae", but should be a single letter that
-looks like an "a" entirely fused with an "e".
-
-=item *
-
 "χρονος" is six Greek characters that should look kind of like: xpovoc
 
 =item *
@@ -528,20 +478,13 @@ lot like: KAK BAC 3OBYT
 
 "丫二十一" is four Chinese characters that should look like: C<Y=+->
 
-=item *
-
-"Ｈｅｌｌｏ" is five characters that should look like: Hello
-
 =back
 
 If all of those come out right, your Pod viewing setup is working
 fine-- welcome to the 2010s!  If those are full of garbage characters,
 consider viewing this page as HTML at
-L<https://metacpan.org/pod/Text::Unidecode>
-or
 L<http://search.cpan.org/perldoc?Text::Unidecode>
 
-
 If things look mostly okay, but the Malayalam and/or the Chinese are
 just question-marks or empty boxes, it's probably just that your
 computer lacks the fonts for those.
@@ -614,8 +557,6 @@ If you know that the text you're handling is probably in German, and
 you want to apply the "umlaut becomes -e" rule, here's how to do it
 for yourself (and then use Unidecode as I<the fallback> afterwards):
 
-  use utf8;  # <-- probably necessary.
-
   our( %German_Characters ) = qw(
    Ä AE   ä ae
    Ö OE   ö oe
@@ -696,51 +637,12 @@ L<perlunicode> and L<perlunitut>.
 
 =head1 THANKS
 
-Thanks to (in only the sloppiest of sorta-chronological order): 
-Jordan Lachler, Harald Tveit Alvestrand, Melissa Axelrod,
-Abhijit Menon-Sen, Mark-Jason Dominus, Joe Johnston,
-Conrad Heiney, fileformat.info,
+Thanks to (in only the sloppiest of sorta-chronological order): Harald
+Tveit Alvestrand, Abhijit Menon-Sen, Mark-Jason Dominus, Joe Johnston,
+Conrad Heiney,
 Philip Newton, 唐鳳, Tomaž Šolc, Mike Doherty, JT Smith and the
-MadMongers, Arden Ogg, Craig Copris,
-David Cusimano, Brendan Byrd,
-and
-I<many>
-other pals who helped with the ideas or values for Unidecode's
-transliterations, or in the secret F5 tornado in its Perl code.
-
-
-
-=head1 PORTS
-
-Some wonderful people have ported Unidecode to other languages!
-
-=over
-
-=item *
-
-Python: L<https://pypi.python.org/pypi/Unidecode>
-
-=item *
-
-PHP: L<https://github.com/silverstripe-labs/silverstripe-unidecode>
-
-=item *
-
-Ruby: L<http://www.rubydoc.info/gems/unidecode/1.0.0/frames>
-
-=item *
-
-JavaScript: L<https://www.npmjs.org/package/unidecode>
-
-=item *
-
-Java: L<https://github.com/xuender/unidecode>
-
-=back
-
-I can't vouch for the details of each port, but these are clever
-people, so I'm sure they did a fine job.
-
+MadMongers, and I<many> other pals in Unicode's behind-the-scenes F5
+tornado underlying its code.
 
 =head1 SEE ALSO
 
@@ -748,10 +650,6 @@ An article I wrote for I<The Perl Journal> about
 Unidecode:  L<http://interglacial.com/tpj/22/>
 (B<READ IT!>)
 
-Tom Christiansen's
-I<Perl Unicode Cookbook>,
-L<http://www.perl.com/pub/2012/04/perlunicook-standard-preamble.html>
-
 Unicode Consortium: L<http://www.unicode.org/>
 
 Searchable Unihan database:
@@ -771,7 +669,7 @@ Books).>  ISBN: 0658009109
 
 =head1 LICENSE
 
-Copyright (c) 2001, 2014, 2015 Sean M. Burke.
+Copyright (c) 2001, 2014 Sean M. Burke.
 
 Unidecode is distributed under the Perl Artistic License
 ( L<perlartistic> ), namely:
@@ -795,7 +693,7 @@ Unicode Consortium.
 
 =head1 AUTHOR
 
-Your pal, Sean M. Burke C<sburke@cpan.org>
+Sean M. Burke C<sburke@cpan.org>
 
 =cut
 
